@@ -12,7 +12,7 @@ DOCUMENTPATH = os.path.join(BASEPATH, DOCUMENT_PATH_NAME)
 SUPER_FUNC = "super_func"
 
 
-def get_my_logger(file_path, file_name, logger_name=__name__, **kwargs):
+def get_my_logger(file_name, file_path=DOCUMENTPATH, level='DEBUG', logger_name=__name__, **kwargs):
     """
     获取日志记录器
     :param log_path: 日志保存位置
@@ -32,7 +32,7 @@ def get_my_logger(file_path, file_name, logger_name=__name__, **kwargs):
     print(file_path)
 
     logger = getLogger(file_path)
-    logger.setLevel(level=logging.DEBUG)
+    logger.setLevel(level=getattr(logging, level.upper()))
     out_formatter = "%(levelname)s %(filename)s:%(lineno)d %(asctime)s  %(message)s"
     # 设置输出控制台
     stream_handler = logging.StreamHandler()
@@ -231,7 +231,7 @@ class MyLogger(logging.Logger):
     pass
 
 
-logger = get_my_logger(DOCUMENTPATH, "logging")
+logger = get_my_logger("logging")
 
 if __name__ == "__main__":
     # logger.debug('s')
