@@ -384,7 +384,8 @@ class BaseJoinView(APIView, Select):
     FORBID_VALUES = dict(**Select.FORBID_VALUES, **{CHOOSE_GROUP: ["password"]})
 
     @relevance_vaild_legal_decorator
-    def get(self, request, obj, obj_serializer, obj_relevance=None, mapping: dict = None):
+    def get(self, request, obj, obj_serializer, obj_relevance=None, m_to_m_obj=None, mapping: dict = None,
+            m_to_m_mapping=None):
         """
         扩展返回字段（关联表）
         1、获取queryset
@@ -398,11 +399,12 @@ class BaseJoinView(APIView, Select):
         """
         results, queryset, current_page_queryset = self.find(obj, request.GET, obj_serializer)
         if results.data and results.data.result and mapping and obj_relevance:
-            result = self.extend_result_field(obj_relevance, obj_serializer, mapping, current_page_queryset)
+            result = self.extend_result_field(obj_serializer, obj_relevance, m_to_m_obj, mapping, m_to_m_mapping,
+                                              current_page_queryset)
             results.data.result = result
         return RESTResponse(results)
 
-    def extend_result_field(self, obj_relevance, obj_serializer, mapping, queryset):
+    def extend_result_field(self, obj_serializer, obj_relevance, m_to_m_obj, mapping, m_to_m_mapping, queryset):
         """
         扩展字段
         1、获取关联表
@@ -412,34 +414,49 @@ class BaseJoinView(APIView, Select):
         :param queryset:
         :return:
         """
-        # 获取关联表
-        relevance_name = obj_relevance.__name__.lower()
+
         result = []
         # 遍历结果集
         for item in queryset:
             item_result = item if isinstance(item, dict) else dict(obj_serializer(item).data)
-            # 获取queryset中的外键对象
-            _obj = getattr(item, relevance_name)
-            # 对结果集进行字段扩展
-            for key in mapping:
-                child_obj = _obj
-                if child_obj:
-                    # 多级 关联
-                    if "." in mapping[key]:
-                        attrs = mapping[key].split(".")
-                        # 多级 关联的外键对象
-                        child_obj = getattr(_obj, attrs[0])
-                        for attr in attrs[1:]:
-                            child_obj = getattr(child_obj, attr)
-                        item_result[key] = child_obj
-                    else:
-                        item_result[key] = getattr(_obj, mapping[key], None)
-                else:
-                    item_result[key] = None
-
+            self.extend_m_to_m_field(item, item_result, m_to_m_obj, m_to_m_mapping)
+            self.extend_relevance_field(item, item_result, obj_relevance, mapping)
             result.append(item_result)
         return result
 
+    def extend_m_to_m_field(self, item, item_result, m_to_m_obj, m_to_m_mapping):
+        if m_to_m_obj:
+            m_to_m_name = m_to_m_obj.__name__.lower()
+            item_result[m_to_m_name] = []
+            m_to_m = getattr(item, m_to_m_name).all()
+            for m_to_m_obj in m_to_m:
+                for key in m_to_m_mapping:
+                    value = getattr(m_to_m_obj, m_to_m_mapping[key])
+                    if value:
+                        item_result[key].append(value)
+
+    def extend_relevance_field(self, item, item_result, obj_relevance, mapping):
+        # 获取关联表
+        relevance_name = obj_relevance.__name__.lower()
+        # 获取queryset中的外键对象
+        _obj = getattr(item, relevance_name)
+        # 对结果集进行字段扩展
+        for key in mapping:
+            child_obj = _obj
+            if child_obj:
+                # 多级 关联
+                if "." in mapping[key]:
+                    attrs = mapping[key].split(".")
+                    # 多级 关联的外键对象
+                    child_obj = getattr(_obj, attrs[0])
+                    for attr in attrs[1:]:
+                        child_obj = getattr(child_obj, attr)
+                    item_result[key] = child_obj
+                else:
+                    item_result[key] = getattr(_obj, mapping[key], None)
+            else:
+                item_result[key] = None
+
     def get_queryset(self, obj, data) -> (QuerySet, QuerySet):
 
         drop_group = data.get(self.CHOOSE_GROUP)
