@@ -36,7 +36,7 @@ class BaseArgsParsing:
         item = data.get(self.SORT)
         field = default_field
         sort = default_sort
-        assert (not (default_field and default_sort)) or (
+        assert (default_field and default_sort) or (
             (not default_field) and (not default_sort)
         ), f"default_field={default_field}, default_sort={default_sort}"
         if item:
