@@ -16,9 +16,9 @@ class ESRequests:
     ESSERVER_VERSION = DEFAULT_ESSERVER_VERSION
 
     def __new__(cls, *args, **kwargs):
-        ES_URL = kwargs.pop("ES_URL")
-        INDEX = kwargs.pop("INDEX")
-        ESSERVER_VERSION = kwargs.pop("ESSERVER_VERSION")
+        ES_URL = kwargs.pop("ES_URL", None)
+        INDEX = kwargs.pop("INDEX", None)
+        ESSERVER_VERSION = kwargs.pop("ESSERVER_VERSION", None)
         if ES_URL:
             cls.ES_URL = ES_URL
         if INDEX:
